/********************************************************************
 Copyright (c) 2006-2008, Gregory Fleischer (gfleischer@gmail.com)
 License: Revised BSD (see LICENSE file)
********************************************************************/

/*
create tables script for DLDOS / MySQL
*/

create table countries (
	id char(2) not null primary key,
	description varchar(64) not null
) engine=InnoDB;

create table business_types (
	id varchar(4) not null primary key,
	description varchar(32) not null
) engine=InnoDB;

create table business_sub_types (
	id varchar(8) not null primary key,
	description varchar(32) not null
) engine=InnoDB;

create table breach_types (
	id varchar(32) not null primary key
) engine=InnoDB;

create table inside_outsides (
	id varchar(32) not null primary key
) engine=InnoDB;

create table data_types (
	id varchar(16) not null primary key,
	description varchar(32) not null
) engine=InnoDB;

create table data_type2s (
	id varchar(16) not null primary key,
	description varchar(32) not null
) engine=InnoDB;

create table import (
	date            varchar(10) not null,
	name		varchar(256) not null,
	country		char(2),
	business_type	varchar(4),
	business_sub_type	varchar(8),
	breach_type	varchar(32),
	data_type	varchar(16),
	data_type2	varchar(16),
	inside_outside	varchar(32),
	third_party	varchar(8),
	third_party_name varchar(256),
	total_affected  varchar(16),
	ref_page	varchar(64),
	uid		varchar(8) primary key,
	xref1		varchar(16),
	stock_symbol	varchar(8),
	data_recovered	varchar(8),
	consumer_lawsuit varchar(8),
	arrest_prosecution varchar(8)
) engine=InnoDB;

create table dataloss (
	id              int   not null auto_increment primary key,
	date            date  not null,
	name		varchar(256) not null,
	country_id	char(2) not null,
		constraint fk_dataloss_country foreign key (country_id) references countries (id),
	business_type_id	varchar(4) not null,
		constraint fk_dataloss_business_type foreign key (business_type_id) references business_types (id),
	business_sub_type_id	varchar(8),
		constraint fk_dataloss_business_sub_type foreign key (business_sub_type_id) references business_sub_types (id),
	breach_type_id	varchar(32) not null,
		constraint fk_dataloss_breach_type foreign key (breach_type_id) references breach_types (id),
	data_type_id	varchar(16) not null,
		constraint fk_dataloss_data_type foreign key (data_type_id) references data_types (id),
	data_type2_id	varchar(16) not null,
		constraint fk_dataloss_data_type2 foreign key (data_type2_id) references data_type2s (id),
	inside_outside_id	varchar(32) not null,
		constraint fk_dataloss_inside_outside foreign key (inside_outside_id) references inside_outsides (id),
	third_party	varchar(8) not null,
		constraint chk_dataloss_third_party check third_party in ('Yes', 'No', '?'),
	third_party_name varchar(256),
	total_affected  varchar(64) not null,
	ref_page	varchar(64),
	uid		varchar(8) not null unique,
	xref1		varchar(16),
	stock_symbol	varchar(8),
	data_recovered	varchar(8) not null,
		constraint chk_dataloss_data_recovered check data_recovered in ('Yes', 'No', 'Partial', 'Unknown'),
	consumer_lawsuit varchar(8) not null,
		constraint chk_dataloss_consumer_lawsuit check consumer_lawsuit in ('Yes', 'No', 'Unknown'),
	arrest_prosecution varchar(8) not null,
		constraint chk_dataloss_arreset_prosecution check arreset_prosecution in ('Yes', 'No', 'Unknown')
) engine=InnoDB;

/* eof */
